import axios from 'axios'
import store from '@/store'
import { getToken } from '@/utils/auth'
import { MessageBox, Message } from 'element-ui'

//创建axios实例
const service = axios.create({
    baseURL: process.env.VUE_APP_BASE_API, // url = base url + request url
    // withCredentials: true, // 跨域请求时发送cookies
    timeout: 5000 // 请求超时
})

//请求拦截器
// service.interceptors.request.use(
//     config => {
//         // do something before request is sent

//         if (store.getters.token) {
//             // 让每个请求携带令牌
//             // ['X-Token']是自定义头密钥
//             // 请根据实际情况修改
//             config.headers['X-Token'] = getToken()
//         }
//         return config
//     },
//     error => {
//         // do something with request error
//         console.log(error) // for debug
//         return Promise.reject(error)
//     }
// )

//请求拦截器
service.interceptors.response.use(
    /**
     * 如果您想要获取诸如头或状态之类的http信息
     * 请返回response=>response
    */
  
    /**
     * 通过自定义代码确定请求状态
     * 这里只是一个例子
     * 您还可以通过HTTP状态代码判断状态
     */
    response => {
      const res = response.data
  
      // 如果自定义代码不是200，则判断为错误。
      if (res.code !== 200) {
        Message({
          message: res.message || 'Error',
          type: 'error',
          duration: 5 * 1000
        })
  
        // 50008:非法令牌；50012:其他客户端登录；50014:令牌过期；
        if (res.code === 50008 || res.code === 50012 || res.code === 50014) {
          // to re-login
          MessageBox.confirm('您已注销，您可以取消以停留在此页，或重新登录', '确认注销', {
            confirmButtonText: '重新登录',
            cancelButtonText: '取消',
            type: 'warning'
          }).then(() => {
            store.dispatch('user/resetToken').then(() => {
              location.reload()
            })
          })
        }
        return Promise.reject(new Error(res.message || 'Error'))
      } else {
        return res
      }
    },
    error => {
      console.log('err' + error) // for debug
      Message({
        message: error.message,
        type: 'error',
        duration: 5 * 1000
      })
      return Promise.reject(error)
    }
  )
  export default service